#
# spec file
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define pkg_name    phpunit

%define flavor php8%{nil}
%if "%{flavor}" == "" || (0%{?suse_version} >= 1550 && "%{flavor}" == "php7")
%define php_name php
%define pkg_pref %nil
ExclusiveArch:  do-not-build
%else
%define php_name %{flavor}
%define pkg_pref %{flavor}-
%endif

Name:           %{pkg_pref}phpunit
Version:        9.5.28
Release:        1.4
Summary:        Testing framework for PHP
License:        BSD-2-Clause
Group:          Development/Tools/Building
URL:            https://phpunit.de/
Source:         https://phar.phpunit.de/phpunit-%{version}.phar
Source1:        https://phar.phpunit.de/phpunit-%{version}.phar.asc
Source2:        %{pkg_name}.keyring
Source3:        https://raw.githubusercontent.com/sebastianbergmann/phpunit/%{version}/LICENSE
Source4:        https://raw.githubusercontent.com/sebastianbergmann/phpunit/%{version}/README.md
Source5:        macros.phpunit
Source6:        %{pkg_name}.rpmlintrc
BuildRequires:  %{php_name}
Requires:       php-dom
Requires:       php-json
Requires:       php-phar
Requires:       %{php_name}
Obsoletes:      php7-phpunit6
Obsoletes:      php7-phpunit7_0
Obsoletes:      php7-phpunit8
Provides:       php-phpunit = %{version}
Obsoletes:      php-phpunit < %{version}
BuildArch:      noarch

%description
PHPUnit is a programmer-oriented testing framework for PHP. It is an instance of the xUnit architecture for unit testing frameworks.

%prep
cp %{SOURCE3} %{SOURCE4} .

%build
# empty section

%install
# Install compiled phar file
install -d -m 0750 %{buildroot}%{_bindir}
install -m 0755 %{SOURCE0} %{buildroot}%{_bindir}/phpunit
# Install macros specific for this version of PHPUnit to be used by other applications
install -d -m 0750 %{buildroot}%{_rpmmacrodir}
install -m 0644 %{SOURCE5} %{buildroot}%{_rpmmacrodir}/macros.phpunit

%files
%license LICENSE
%doc README.md
%{_bindir}/phpunit
%{_rpmmacrodir}/macros.phpunit

%changelog
* Fri Jan 20 2023 Arjen de Korte <suse+build@de-korte.org>
- Refresh 9.5.28 source files as they seem to have been republished
* Tue Jan 17 2023 pgajdos@suse.com
- %%nil flavor implies Name: phpunit
* Thu Jan 12 2023 pgajdos@suse.com
- package reworked, php7 and php8 flavors
- Update package to release 9.5.28
  * https://github.com/sebastianbergmann/phpunit/blob/9.5/ChangeLog-9.5.md
* Wed Aug 19 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%_rpmmacrodir instead of wrong %%{_libexecdir}/rpm/macros.d
  (libexecdir changes to /usr/libexec).
* Sun Dec 15 2019 Arjen de Korte <suse+build@de-korte.org>
- Update package to release 8.5.0
  * https://github.com/sebastianbergmann/phpunit/blob/8.5/ChangeLog-8.5.md
- Update package to release 8.4.3
  * https://github.com/sebastianbergmann/phpunit/blob/8.4.3/ChangeLog-8.4.md
- Update package to release 8.3.5
  * https://github.com/sebastianbergmann/phpunit/blob/8.3.5/ChangeLog-8.3.md
- Update package to release 8.2.5
  * https://github.com/sebastianbergmann/phpunit/blob/8.2.5/ChangeLog-8.2.md
- Update package to release 8.1.6
  * https://github.com/sebastianbergmann/phpunit/blob/8.1.6/ChangeLog-8.1.md
* Fri Mar 29 2019 suse+build@de-korte.org
- Update package to release 8.0.6
  * Fixed #3564: Production code uses class from test suite's fixture
* Tue Mar 26 2019 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Added obsoletes statements to php7-phpunit7_0 and php7-phpunit6 to allow
  a smooth update
* Sun Mar 17 2019 suse+build@de-korte.org
- Update package to release 8.0.5
  * Fixed #3480: Wrong return type declaration for TestCase::getExpectedExceptionMessage()
    and TestCase::getExpectedExceptionMessageRegExp()
  * Fixed #3532: Wrong default value for cacheResult in phpunit.xsd
  * Fixed #3539: Wrong default value for resolveDependencies in
    phpunit.xsd
  * Fixed #3550: Check for valid attribute names in assertObjectHasAttribute()
    is too strict
  * Fixed #3555: Extension loader only allows objects that implement
    TestHook but should also allow Hook
  * Fixed #3560: TestDox does not work when tests are filtered
* Tue Feb 19 2019 suse+build@de-korte.org
- Update package to release 8.0.4
  * Fixed #3530: generateClassFromWsdl() does not handle methods
    with multiple output values
  * Fixed #3531: Test suite fails on warning
  * Fixed #3534: Wrong message in ConstraintTestCase
  * Fixed #3535: TypeError in Command
* Mon Feb 18 2019 suse+build@de-korte.org
- Change install location of macros.phpunit
* Sat Feb 16 2019 suse+build@de-korte.org
- Update package to release 8.0.3
  * Fixed #3011: Unsupported PHPT --SECTION-- throws unhandled
    exception
  * Fixed #3461: StringEndsWith matches too loosely
  * Fixed #3515: Random order seed is only printed in verbose mode
  * Fixed #3517: Useless error message when depending on test that
    does not exist
* Fri Feb 15 2019 suse+build@de-korte.org
- Add macros.phpunit to fixup unit tests for PHPUnit
* Wed Feb 13 2019 suse+build@de-korte.org
- Updated package to release 8.0.2
  * Fixed #3352: Using phpunit.phar with PHPDBG does not work with
    auto_globals_jit=On
  * Fixed #3508: TypeError in Fileloader when trying to load
    nonexistent file
  * Fixed #3511: Asserting that an object is contained in an
    iterable while using == instead of === is no longer possible
* Wed Feb  6 2019 suse+build@de-korte.org
- Only build for supported PHP versions
- Added source verification
* Wed Feb  6 2019 suse+build@de-korte.org
- Remove fixup of shebang (causes a SHA1 failure)
* Tue Feb  5 2019 suse+build@de-korte.org
- Initial release for php7-phpunit8
